==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/QGpGuiTools/src/QGpGuiTools.h <==
#ifndef QGPGUITOOLS_HEADERS
#define QGPGUITOOLS_HEADERS

// All headers of QGpGuiTools library

#include "Application.h"
#include "BugReport.h"
#include "CheckComboBox.h"
#include "CheckComboBoxModel.h"
#include "ColorButton.h"
#include "ColorHistogram.h"
#include "ColumnTextColumnsProperties.h"
#include "ColumnTextDelegate.h"
#include "ColumnTextItem.h"
#include "ColumnTextLinesProperties.h"
#include "ColumnTextSectionsProperties.h"
#include "ColumnTextWidget.h"
#include "ConnectionParam.h"
#include "Dialog.h"
#include "DockWidget.h"
#include "DoubleSpinBox.h"
#include "ExpandTabTitle.h"
#include "ExpandTabWidget.h"
#include "ExpressionEditor.h"
#include "FindReplaceWidget.h"
#include "FrozenWidget.h"
#include "GuiGlobal.h"
#include "GuiMessage.h"
#include "HttpAccess.h"
#include "HttpProxy.h"
#include "HttpProxyList.h"
#include "HttpProxyObject.h"
#include "HttpProxyScript.h"
#include "LogView.h"
#include "LogWidget.h"
#include "LoopProgressWidget.h"
#include "MessageBox.h"
#include "MultiDocumentEnvironment.h"
#include "MultiDocumentSubWindow.h"
#include "MultiDocumentTab.h"
#include "MultiDocumentTabBar.h"
#include "MultiDocumentTabWidget.h"
#include "MultiDocumentWindow.h"
#include "PluginApplication.h"
#include "PrintDialogWrapper.h"
#include "ProgressBar.h"
#include "PropertyContext.h"
#include "PropertyItem.h"
#include "PropertyProxy.h"
#include "PropertyValue.h"
#include "PropertyWidget.h"
#include "QGpGuiToolsDLLExport.h"
#include "RegExpRowSelector.h"
#include "SendMail.h"
#include "Settings.h"
#include "SizeGrip.h"
#include "TitledWidget.h"
#include "UpdateIcon.h"
#include "WidgetRect.h"
#include "XMLEditor.h"
#include "XMLItem.h"
#include "ui_Attachments.h"
#include "ui_BugReport.h"
#include "ui_ColumnTextColumnsProperties.h"
#include "ui_ColumnTextLinesProperties.h"
#include "ui_ColumnTextSectionsProperties.h"
#include "ui_ColumnTextWidget.h"
#include "ui_ConnectionParam.h"
#include "ui_ExpressionEditor.h"
#include "ui_FindReplaceWidget.h"
#include "ui_MessageBox.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace QGpGuiTools;
#endif

#endif // QGPGUITOOLS_HEADERS

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/QGpGuiTools/src/QGpGuiTools.h <==
#ifndef QGPGUITOOLS_HEADERS
#define QGPGUITOOLS_HEADERS

// All headers of QGpGuiTools library

#include "Application.h"
#include "BugReport.h"
#include "CheckComboBox.h"
#include "CheckComboBoxModel.h"
#include "ColorButton.h"
#include "ColorHistogram.h"
#include "ColumnTextColumnsProperties.h"
#include "ColumnTextDelegate.h"
#include "ColumnTextItem.h"
#include "ColumnTextLinesProperties.h"
#include "ColumnTextSectionsProperties.h"
#include "ColumnTextWidget.h"
#include "Dialog.h"
#include "DockWidget.h"
#include "DoubleSpinBox.h"
#include "ExpandTabTitle.h"
#include "ExpandTabWidget.h"
#include "ExpressionEditor.h"
#include "FindReplaceWidget.h"
#include "FrozenWidget.h"
#include "GuiGlobal.h"
#include "GuiMessage.h"
#include "HttpAccess.h"
#include "ItemDelegate.h"
#include "LogView.h"
#include "LogWidget.h"
#include "LoopProgressWidget.h"
#include "MessageBox.h"
#include "MultiDocumentEnvironment.h"
#include "MultiDocumentSubWindow.h"
#include "MultiDocumentTab.h"
#include "MultiDocumentTabBar.h"
#include "MultiDocumentTabWidget.h"
#include "MultiDocumentWindow.h"
#include "PluginApplication.h"
#include "PrintDialogWrapper.h"
#include "ProgressBar.h"
#include "PropertyCategory.h"
#include "PropertyContext.h"
#include "PropertyItem.h"
#include "PropertyProxy.h"
#include "PropertyTab.h"
#include "PropertyValue.h"
#include "PropertyWidget.h"
#include "QGpGuiToolsDLLExport.h"
#include "RegExpRowSelector.h"
#include "SendMail.h"
#include "Settings.h"
#include "SizeGrip.h"
#include "TableView.h"
#include "TitledWidget.h"
#include "UpdateIcon.h"
#include "WidgetRect.h"
#include "XMLEditor.h"
#include "XMLItem.h"
#include "ui_Attachments.h"
#include "ui_BugReport.h"
#include "ui_ColumnTextColumnsProperties.h"
#include "ui_ColumnTextLinesProperties.h"
#include "ui_ColumnTextSectionsProperties.h"
#include "ui_ColumnTextWidget.h"
#include "ui_ExpressionEditor.h"
#include "ui_FindReplaceWidget.h"
#include "ui_MessageBox.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace QGpGuiTools;
#endif

#endif // QGPGUITOOLS_HEADERS
